Learn R Programming

prioGene (version 1.0.1)

genes_mat: a one-to-many matrix of GO term and gene

Description

the first column is the gene symbol, the second column is the go terms

Usage

genes_mat

Arguments

Format

A matrix with 45 rows and 3 columns

Details

the third column is the number of go terms