Learn R Programming

prioGene (version 1.0.1)

get_R_0: Title get the vector of initial disease risk scores for all genes

Description

Title get the vector of initial disease risk scores for all genes

Usage

get_R_0(disease_gene, node_weight, f = 1)

Arguments

disease_gene

a matrix of a column of genes

node_weight

a matrix, genes and their weights

f

an integer parameter to measure the significance of disease genes and candidate genes

Value

a vector

Examples

Run this code
# NOT RUN {
get_R_0(dise_gene,node_weight,1)
# }

Run the code above in your browser using DataLab