Learn R Programming

prioGene (version 1.0.1)

get_net_disease_term: Title Get the GO terms for each pair of nodes in the network

Description

Title Get the GO terms for each pair of nodes in the network

Usage

get_net_disease_term(genes_mat, net_disease)

Arguments

genes_mat

a one-to-many matrix of GO term and gene

net_disease

a disease related network, matrix

Value

a matrix

Examples

Run this code
# NOT RUN {
get_net_disease_term(genes_mat,net_disease)
# }

Run the code above in your browser using DataLab