Learn R Programming

prioGene (version 1.0.1)

net_disease_term: GO terms for each pair of nodes in the network

Description

the first two columns is the network

Usage

net_disease_term

Arguments

Format

A matrix with 25 rows and 4 columns

Details

the third column is the go terms,the fourth column is the number of go terms

the fourth column is the number of go terms