Rdocumentation
powered by
Learn R Programming
prioGene (version 1.0.1)
R_0: the vector of initial disease risk scores for all genes
Description
the vector of initial disease risk scores for all genes
Usage
R_0
Arguments
Format
A vector of 45 number