powered by
Title get the vector of initial disease risk scores for all genes
get_R_0(disease_gene, node_weight, f = 1)
a matrix of a column of genes
a matrix, genes and their weights
an integer parameter to measure the significance of disease genes and candidate genes
a vector
# NOT RUN { get_R_0(dise_gene,node_weight,1) # }
Run the code above in your browser using DataLab