powered by
the first two columns is the network
net_disease_term
A matrix with 25 rows and 4 columns
the third column is the go terms,the fourth column is the number of go terms
the fourth column is the number of go terms